@@ -203,7 +203,7 @@ class SciKitNearestNeighbors:
 
 
 class RedisIndex:
-    def __init__(self, space, dim, index_factory=None,redis_credentials=None,max_elements=1024, ef_construction=200, M=16, overwrite=False):
+    def __init__(self, space, dim, index_factory=None,redis_credentials=None,max_elements=1024, ef_construction=200, M=16, overwrite=True):
         self.space = space
         self.dim = dim
         self.max_elements = max_elements
@@ -236,13 +236,13 @@ class RedisIndex:
         return super().get_items([item])[0]
 
     def user_keys(self):
-        return self.redis.keys("user:*")
+        return [s.decode()[5:] for s in self.redis.keys("user:*")]
 
     def item_keys(self):
-        return self.redis.keys("item:*")
+        return [s.decode()[5:] for s in self.redis.keys("item:*")]
 
     def vector_keys(self):
-        return self.redis.keys("vec:*")
+        return [s.decode()[4:] for s in self.redis.keys("vec:*")]
 
     def search(self, data, k=1,partition=None):
         query_vector = np.array(data).astype(np.float32).tobytes()
@@ -344,4 +344,5 @@ if __name__=="__main__":
     sim.add_items(data,aids,partition="a")
     sim.add_items(data,bids,partition="b")
     # print(sim.search(data[0],k=10,partition=None))
-    # print(sim.get_items(aids[:10]))
\ No newline at end of file
+    # print(sim.get_items(aids[:10]))
+    print (sim.item_keys())
\ No newline at end of file
